@@ -18,11 +18,11 @@ class EmailValidator < ActiveModel::EachValidator
     # Check if domain is disposable
     if r && options[:ban_disposable_email]
       require 'valid_email/ban_disposable_email_validator'
-      r = BanDisposableEmailValidator.new(:attributes => attributes, message: options[:message]).validate(record)
+      r = BanDisposableEmailValidator.new(:attributes => attributes, message: options[:message], partial: options[:partial]).validate(record)
     end
     unless r
       msg = (options[:message] || I18n.t(:invalid, :scope => "valid_email.validations.email"))
-      record.errors.add attribute, message: (msg % {value: value})
+      record.errors.add attribute, message: I18n.interpolate(msg, value: value)
     end
   end
 end
