@@ -3,7 +3,10 @@ require 'valid_email'
 
 RSpec.configure do |config|
   config.order = :random
-  config.profile_examples = 10
   config.raise_errors_for_deprecations!
   Kernel.srand config.seed
+
+  if ENV['CI']
+    config.warnings = true
+  end
 end
